@@ -26,10 +26,13 @@ class app(object):
   root        = os.environ.get("APP_ROOT",             CWD)
   author      = os.environ.get("APP_AUTHOR",           "Unknown Author")
   description = os.environ.get("APP_DESCRIPTION",      "A baseweb app")
+  scheme      = os.environ.get("APP_COLOR_SCHEME",     "dark")
   color       = os.environ.get("APP_COLOR",            "rgb(21, 101, 192)")
+  color_name  = os.environ.get("APP_COLOR_NAME",       "blue") + " darken-3" if scheme == "dark" else ""
   bgcolor     = os.environ.get("APP_BACKGROUND_COLOR", "rgb(21, 101, 192)")
   style       = os.environ.get("APP_STYLE",            "web")
   icon        = os.environ.get("APP_ICON",             None)
+  socketio    = os.environ.get("APP_SOCKETIO",         "yes").lower() in [ "yes", "true", "ok" ]
 
 logger.debug("baseAdmin config = " + str({
   "app" : {
@@ -39,8 +42,12 @@ logger.debug("baseAdmin config = " + str({
     "root"        : app.root,
     "author"      : app.author,
     "description" : app.description,
+    "scheme"      : app.scheme,
     "color"       : app.color,
+    "color_name"  : app.color_name,
     "bgcolor"     : app.bgcolor,
-    "style"       : app.style        
+    "style"       : app.style,
+    "icon"        : app.icon,
+    "socketio"    : app.socketio
   }
 }))
